xWMB: xarray-friendly analysis of Water Mass Transformation Budgets (WMB)
=========================================================================

**xwmb** is a Python package for water mass transformation analysis
that leverages xarray functionality.

Overview
----------

.. toctree::
   :maxdepth: 1

   objective
   
.. toctree::
   :maxdepth: 2

   examples

Installation and Contributing
-----------------------------

.. toctree::
   :maxdepth: 1

   install
   contrib


Help & Reference
----------------

.. toctree::
   :maxdepth: 1

   api


Quick Install
-------------

Install from conda-forge:

.. code-block:: bash

   conda install -c conda-forge xwmb

Install from PyPI:

.. code-block:: bash

   pip install xwmb


Install from GitHub:

.. code-block:: bash

   pip install git+https://github.com/hdrake/xwmb.git